summaryrefslogtreecommitdiff
path: root/src/file.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/file.h')
-rw-r--r--src/file.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/file.h b/src/file.h
index 7738df6..7165936 100644
--- a/src/file.h
+++ b/src/file.h
@@ -20,6 +20,8 @@
#include "activefor.h"
#include "network.h"
+#include "server_configuration_struct.h"
+#include "client_configuration_struct.h"
#include <openssl/ssl.h>
#ifndef _JS_FILE_H
@@ -31,7 +33,9 @@
#define F_RVALUE 4
#define F_MIDDLE 5
-ConfigurationT parsefile(char*, int*); /* parse the cfg file */
+int parse_line(char* buff, char* tab1, char* tab2); /* parse one line of the file */
+ServerConfiguration* parsefile(char*, int*); /* parse the cfg file */
+ClientConfiguration* cparsefile(char*, int*); /* parse the client's cfg file */
#endif